@@ -10,4 +10,10 @@ def run(stud_file: dict, options: argparse.Namespace) -> None:
         if key != 'command':
             val = getattr(options, key)
             cmd = f'{key} = {repr(val)}\n' + cmd
-    calligraphy_scripting.runner.execute(cmd)
+
+    if '.variables' in stud_file.keys():
+        for key in stud_file['.variables']:
+            val = stud_file['.variables'][key]
+            cmd = f'{key} = {repr(val)}\n' + cmd
+            
+    calligraphy_scripting.runner.execute(cmd, [])
